@@ -75,6 +75,22 @@ The version of the Fixflo API to use, defaults to:
 
     /api/$Business::Fixflo::API_VERSION
 
+=head2 ua_proxy_settings 
+
+The custom proxy settings for the user agent class
+The format is identical to LWP::UserAgent::proxy
+
+    my $ff = Business::Fixflo->new( ... );
+
+    $ff->client->ua_proxy_settings(
+        [
+            ftp => 'http://ftp.example.com:8001/',
+	    [ 'http', 'https' ] => 'http://http.example.com:8001/',
+	]
+    );
+
+
+
 =cut
 
 has [ qw/ custom_domain / ] => (
@@ -126,6 +142,17 @@ has api_path => (
     default  => sub { '/api/' . $Business::Fixflo::API_VERSION },
 );
 
+has ua_proxy_settings => (
+    is       => 'rw',
+    isa => sub {
+        confess( "$_[0] is not an ARRAY ref" )
+            if ref $_[0] ne 'ARRAY';
+    },
+    required => 0,
+    default  => sub { [] },
+);
+
+
 sub BUILD {
     my ( $self ) = @_;
 
@@ -388,6 +415,10 @@ sub _api_request {
         }
     }
 
+    if ( @{ $self->ua_proxy_settings } ) {
+        $ua->proxy( $self->ua_proxy_settings );
+    }
+
     my $res = $ua->request( $req );
 
     # work around the fact that a 200 status code can still mean a problem
